@@ -31,7 +31,7 @@ class Slack:
         slack_client = WebClient(self.slack_api_token)
         self.show_debug = show_debug
 
-    @se
+
     def send_slack(
         self,
         slack_channel,
@@ -93,14 +93,13 @@ class Twilio:
         self.twilio_api_token = twilio_api_token
         twilio_client = Client(
             self.account_sid,
-            self.twilio_API_token
+            self.twilio_api_token
         )
         self.twilio_client = twilio_client
         self.from_tel = from_tel
         self.show_debug = show_debug
     
 
-    @se
     def send_sms(self, message, send_to, from_tel=None):
         """
         RETURN : {"status": True/False, "error": error_msg},
@@ -152,7 +151,7 @@ def send_process(
     slack_to=None, email_to=None,
     sms_to=None, txt_file_to=None,
     csv_file_to=None, file_to_s3=False,
-    show_debug=True, color=WHITE,
+    show_debug=True, color=None,
     slack_client=None,
     twilio_client=None
 ):
@@ -161,6 +160,8 @@ def send_process(
     # make sure everything is clean
     if this_file_name is None:
         this_file_name = ""
+    if color is None:
+        color = WHITE
     msg, label, this_file_name = str(msg), str(label), str(this_file_name)
     # clean list
     if slack_to is not None:
